==> android-4.0.1.2-sources.jar: android/widget/Switch.java <==
package android.widget;
public class Switch
  extends android.widget.CompoundButton
{
public  Switch(android.content.Context context) { super((android.content.Context)null,(android.util.AttributeSet)null,0); throw new RuntimeException("Stub!"); }
public  Switch(android.content.Context context, android.util.AttributeSet attrs) { super((android.content.Context)null,(android.util.AttributeSet)null,0); throw new RuntimeException("Stub!"); }
public  Switch(android.content.Context context, android.util.AttributeSet attrs, int defStyle) { super((android.content.Context)null,(android.util.AttributeSet)null,0); throw new RuntimeException("Stub!"); }
public  void setSwitchTextAppearance(android.content.Context context, int resid) { throw new RuntimeException("Stub!"); }
public  void setSwitchTypeface(android.graphics.Typeface tf, int style) { throw new RuntimeException("Stub!"); }
public  void setSwitchTypeface(android.graphics.Typeface tf) { throw new RuntimeException("Stub!"); }
public  java.lang.CharSequence getTextOn() { throw new RuntimeException("Stub!"); }
public  void setTextOn(java.lang.CharSequence textOn) { throw new RuntimeException("Stub!"); }
public  java.lang.CharSequence getTextOff() { throw new RuntimeException("Stub!"); }
public  void setTextOff(java.lang.CharSequence textOff) { throw new RuntimeException("Stub!"); }
public  void onMeasure(int widthMeasureSpec, int heightMeasureSpec) { throw new RuntimeException("Stub!"); }
public  void onPopulateAccessibilityEvent(android.view.accessibility.AccessibilityEvent event) { throw new RuntimeException("Stub!"); }
public  boolean onTouchEvent(android.view.MotionEvent ev) { throw new RuntimeException("Stub!"); }
public  void setChecked(boolean checked) { throw new RuntimeException("Stub!"); }
protected  void onLayout(boolean changed, int left, int top, int right, int bottom) { throw new RuntimeException("Stub!"); }
protected  void onDraw(android.graphics.Canvas canvas) { throw new RuntimeException("Stub!"); }
public  int getCompoundPaddingRight() { throw new RuntimeException("Stub!"); }
protected  int[] onCreateDrawableState(int extraSpace) { throw new RuntimeException("Stub!"); }
protected  void drawableStateChanged() { throw new RuntimeException("Stub!"); }
protected  boolean verifyDrawable(android.graphics.drawable.Drawable who) { throw new RuntimeException("Stub!"); }
public  void jumpDrawablesToCurrentState() { throw new RuntimeException("Stub!"); }
}

==> android-4.1.1.4-sources.jar: android/widget/Switch.java <==
package android.widget;
public class Switch
  extends android.widget.CompoundButton
{
public  Switch(android.content.Context context) { super((android.content.Context)null,(android.util.AttributeSet)null,0); throw new RuntimeException("Stub!"); }
public  Switch(android.content.Context context, android.util.AttributeSet attrs) { super((android.content.Context)null,(android.util.AttributeSet)null,0); throw new RuntimeException("Stub!"); }
public  Switch(android.content.Context context, android.util.AttributeSet attrs, int defStyle) { super((android.content.Context)null,(android.util.AttributeSet)null,0); throw new RuntimeException("Stub!"); }
public  void setSwitchTextAppearance(android.content.Context context, int resid) { throw new RuntimeException("Stub!"); }
public  void setSwitchTypeface(android.graphics.Typeface tf, int style) { throw new RuntimeException("Stub!"); }
public  void setSwitchTypeface(android.graphics.Typeface tf) { throw new RuntimeException("Stub!"); }
public  void setSwitchPadding(int pixels) { throw new RuntimeException("Stub!"); }
public  int getSwitchPadding() { throw new RuntimeException("Stub!"); }
public  void setSwitchMinWidth(int pixels) { throw new RuntimeException("Stub!"); }
public  int getSwitchMinWidth() { throw new RuntimeException("Stub!"); }
public  void setThumbTextPadding(int pixels) { throw new RuntimeException("Stub!"); }
public  int getThumbTextPadding() { throw new RuntimeException("Stub!"); }
public  void setTrackDrawable(android.graphics.drawable.Drawable track) { throw new RuntimeException("Stub!"); }
public  void setTrackResource(int resId) { throw new RuntimeException("Stub!"); }
public  android.graphics.drawable.Drawable getTrackDrawable() { throw new RuntimeException("Stub!"); }
public  void setThumbDrawable(android.graphics.drawable.Drawable thumb) { throw new RuntimeException("Stub!"); }
public  void setThumbResource(int resId) { throw new RuntimeException("Stub!"); }
public  android.graphics.drawable.Drawable getThumbDrawable() { throw new RuntimeException("Stub!"); }
public  java.lang.CharSequence getTextOn() { throw new RuntimeException("Stub!"); }
public  void setTextOn(java.lang.CharSequence textOn) { throw new RuntimeException("Stub!"); }
public  java.lang.CharSequence getTextOff() { throw new RuntimeException("Stub!"); }
public  void setTextOff(java.lang.CharSequence textOff) { throw new RuntimeException("Stub!"); }
public  void onMeasure(int widthMeasureSpec, int heightMeasureSpec) { throw new RuntimeException("Stub!"); }
public  void onPopulateAccessibilityEvent(android.view.accessibility.AccessibilityEvent event) { throw new RuntimeException("Stub!"); }
public  boolean onTouchEvent(android.view.MotionEvent ev) { throw new RuntimeException("Stub!"); }
public  void setChecked(boolean checked) { throw new RuntimeException("Stub!"); }
protected  void onLayout(boolean changed, int left, int top, int right, int bottom) { throw new RuntimeException("Stub!"); }
protected  void onDraw(android.graphics.Canvas canvas) { throw new RuntimeException("Stub!"); }
public  int getCompoundPaddingRight() { throw new RuntimeException("Stub!"); }
protected  int[] onCreateDrawableState(int extraSpace) { throw new RuntimeException("Stub!"); }
protected  void drawableStateChanged() { throw new RuntimeException("Stub!"); }
protected  boolean verifyDrawable(android.graphics.drawable.Drawable who) { throw new RuntimeException("Stub!"); }
public  void jumpDrawablesToCurrentState() { throw new RuntimeException("Stub!"); }
public  void onInitializeAccessibilityEvent(android.view.accessibility.AccessibilityEvent event) { throw new RuntimeException("Stub!"); }
public  void onInitializeAccessibilityNodeInfo(android.view.accessibility.AccessibilityNodeInfo info) { throw new RuntimeException("Stub!"); }
}
